@@ -5,4 +5,4 @@ OUT=$?
 if [ "$OUT" != 0 ]; then
 	exit 1
 fi
-nosetests test_treetime.py
+pytest test_treetime.py
