@@ -1,6 +1,6 @@
 from __future__ import print_function, division, absolute_import
 import numpy as np
-from treetime import config as ttconf
+from . import config as ttconf
 from .distribution import Distribution
 
 class BranchLenInterpolator (Distribution):
