@@ -1,7 +1,8 @@
 from __future__ import print_function, division, absolute_import
 import numpy as np
-from treetime import config as ttconf
+from . import config as ttconf
 from .distribution import Distribution
+from .utils import clip
 
 def _create_initial_grid(node_dist, branch_dist):
     pass
@@ -65,10 +66,10 @@ def _convolution_integrand(t_val, f, g,
     else:
         # create the tau-grid for the interpolation object in the overlap region
         if inverse_time:
-            tau = np.unique(np.concatenate((g.x, t_val-f.x,[tau_min,tau_max])))
+            tau = np.concatenate((g.x, t_val-f.x,[tau_min,tau_max]))
         else:
-            tau = np.unique(np.concatenate((g.x, f.x-t_val,[tau_min,tau_max])))
-        tau = tau[(tau>tau_min-ttconf.TINY_NUMBER)&(tau<tau_max+ttconf.TINY_NUMBER)]
+            tau = np.concatenate((g.x, f.x-t_val,[tau_min,tau_max]))
+        tau = np.unique(clip(tau, tau_min-ttconf.TINY_NUMBER, tau_max+ttconf.TINY_NUMBER))
         if len(tau)<10:
             tau = np.linspace(tau_min, tau_max, 10)
 
